@@ -44,7 +44,7 @@ def plot_base_bar1(df: pd.DataFrame, title_name='', subtitle_name='', xaxis_name
         yaxis_opts=opts.AxisOpts(name=yaxis_name),
         datazoom_opts=opts.DataZoomOpts(is_show=True)
     )
-    c1.add_xaxis([str(i) for i in _data.index)
+    c1.add_xaxis([str(i) for i in _data.index])
     for icol in ynames:
         c1.add_yaxis(icol, _data[icol].values.tolist())
     c1.set_series_opts(label_opts=opts.LabelOpts(is_show=False))
@@ -111,7 +111,7 @@ def plot_base_line2(df1: pd.DataFrame, df2: pd.DataFrame,
         datazoom_opts=opts.DataZoomOpts(is_show=True)
     )
     c1.extend_axis(yaxis=opts.AxisOpts(name=yaxis_name2,position="right"))
-    c1.add_xaxis(_data1.index.tolist())
+    c1.add_xaxis([str(i) for i in _data.index])
     for icol in _data1.columns:
         c1.add_yaxis(icol, _data1[icol].values.tolist(),yaxis_index=0)
     for icol in _data2.columns:
